/* ***************************************************************************
   *                                                                         *
   *   Kindermann                                   WPK-Produktentwicklung   *
   *                                                Schuljahr 2016/17        *
   *                              WiFi-Thermometer                           *
   *                           (Access-Point-Version)                        *
   *                                                                         *
   ***************************************************************************/


#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <WiFiManager.h>
#include <OneWire.h>
#include <DallasTemperature.h>
#include <WebSocketsServer.h>

#include <DNSServer.h>

#include "index.h"

const char* ssid = "WiFi-Thermometer";
const char* password = "thermometer";

// DNS server
const byte DNS_PORT = 53;
DNSServer dnsServer;


ESP8266WebServer server(80);
WebSocketsServer webSocket=WebSocketsServer(88);

// Accesspoint Parameter ...
IPAddress apIP(192, 168, 4, 1);
IPAddress netMsk(255, 255, 255, 0);

String JSONtxt;
int websockMillis=500;
unsigned long wait001=0UL;
int led1=0;

// DS1820 Setup
#define ONE_WIRE_BUS 2  // DS18B20 pin GPIO2 
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature DS18B20(&oneWire);
float temp=0; 


void tick()
{
  int state = digitalRead(led1);  // liest den Status von GPIO1
  digitalWrite(led1, !state);     // invertiert den Status von GPIO1 
}


void webSocketEvent(uint8_t num, WStype_t type, uint8_t * payload, size_t wslength){
  String payloadString=(const char *)payload;
  
  if(type==WStype_TEXT){
    byte separator=payloadString.indexOf('=');
    String var=payloadString.substring(0,separator);
    String val=payloadString.substring(separator+1);  
    }
}


void setup(void){
  
  pinMode(led1,OUTPUT);
  digitalWrite(led1,LOW);
  pinMode(1, OUTPUT);       // TX
  pinMode(3, INPUT_PULLUP); // Rx
     
  WiFi.mode(WIFI_AP);
    
  uint8_t mac[WL_MAC_ADDR_LENGTH];
  WiFi.softAPmacAddress(mac);
  String macID = String(mac[WL_MAC_ADDR_LENGTH - 2], HEX) +
                 String(mac[WL_MAC_ADDR_LENGTH - 1], HEX);
  macID.toUpperCase();
  String AP_NameString = "WiFi-Thermometer " + macID;

  char AP_NameChar[AP_NameString.length() + 1];
  memset(AP_NameChar, 0, AP_NameString.length() + 1);

  for (int i=0; i<AP_NameString.length(); i++)
  AP_NameChar[i] = AP_NameString.charAt(i);
   
  WiFi.softAP(AP_NameChar, password);

  dnsServer.setErrorReplyCode(DNSReplyCode::NoError);
  dnsServer.start(DNS_PORT, "www.wifi-thermometer.de", apIP);
      
  server.on("/", [](){
    server.send(200, "text/html",MAIN_page);
  });
        
  server.begin();
  webSocket.begin();
  webSocket.onEvent(webSocketEvent);  
}
 
void loop(void){

  dnsServer.processNextRequest();
    
  server.handleClient();
  webSocket.loop();
    
  if(millis()>wait001){
           
      // überprüfen, ob Tx und Rx gebrückt sind ...
      digitalWrite(1, 0);
      delayMicroseconds(2);
      if (digitalRead(3))goto weiter;
      // toggle LED1 ...
      digitalWrite(led1, !digitalRead(led1));
      weiter:
      digitalWrite(1, 1);
            
      DS18B20.requestTemperatures(); 
      temp = DS18B20.getTempCByIndex(0); 
 
      String TempStr = "\"Temperatur\":\"";      
      JSONtxt = "{" + TempStr + temp + "\"}";
      
      webSocket.broadcastTXT(JSONtxt);
      wait001=millis()+websockMillis;    
      } 
} 


